==> fop_0.93.dfsg.1.orig.tar.gz: fop-0.93.dfsg.1.orig/src/java/org/apache/fop/render/rtf/rtflib/rtfdoc/RtfGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: RtfGenerator.java 426576 2006-07-28 15:44:37Z jeremias $ */

package org.apache.fop.render.rtf.rtflib.rtfdoc;

import java.io.IOException;
import java.io.Writer;

/**
 * Represents a generator element which says who generated the RTF document.
 */
public class RtfGenerator extends RtfElement {

    /** Default constructor for the generator element. */
    public RtfGenerator(RtfHeader h, Writer w) throws IOException {
        super(h, w);
    }
    
    /**
     * @see org.apache.fop.render.rtf.rtflib.rtfdoc.RtfElement#writeRtfContent()
     */
    protected void writeRtfContent() throws IOException {
        newLine();
        writeGroupMark(true);
        writeStarControlWord("generator");
        writer.write("Apache XML Graphics RTF Library");
        writer.write(";");
        writeGroupMark(false);
    }

    /**
     * @see org.apache.fop.render.rtf.rtflib.rtfdoc.RtfElement#isEmpty()
     */
    public boolean isEmpty() {
        return false;
    }

}

==> fop_0.95.dfsg.orig.tar.gz: fop-0.95/src/java/org/apache/fop/render/rtf/rtflib/rtfdoc/RtfGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: RtfGenerator.java 627367 2008-02-13 12:03:30Z maxberger $ */

package org.apache.fop.render.rtf.rtflib.rtfdoc;

import java.io.IOException;
import java.io.Writer;

/**
 * Represents a generator element which says who generated the RTF document.
 */
public class RtfGenerator extends RtfElement {

    /** Default constructor for the generator element. */
    public RtfGenerator(RtfHeader h, Writer w) throws IOException {
        super(h, w);
    }
    
    /**
     * {@inheritDoc}
     */
    protected void writeRtfContent() throws IOException {
        newLine();
        writeGroupMark(true);
        writeStarControlWord("generator");
        writer.write("Apache XML Graphics RTF Library");
        writer.write(";");
        writeGroupMark(false);
    }

    /**
     * {@inheritDoc}
     */
    public boolean isEmpty() {
        return false;
    }

}
